<?php

namespace Config;

// Create a new instance of our RouteCollection class.
$routes = Services::routes();

/*
 * --------------------------------------------------------------------
 * Router Setup
 * --------------------------------------------------------------------
 */
$routes->setDefaultNamespace('App\Controllers');
$routes->setDefaultController('Home');
$routes->setDefaultMethod('index');
$routes->setTranslateURIDashes(false);
$routes->set404Override();



$routes->get('login', 'Auth::login');
$routes->post('login', 'Auth::login');
$routes->get('logout', 'Auth::logout');

$routes->group('', ['filter' => 'auth'], function($routes) {
    $routes->get('dashboard', 'Dashboard::index');
  	$routes->get('hotels', 'Hotel::index');
	$routes->get('hotels/create', 'Hotel::create');
	$routes->post('hotels/store', 'Hotel::store');
    
    $routes->group('requests', ['filter' => 'auth'], function($routes) {
    	$routes->get('/', 'Request::index');
    	$routes->get('new', 'Request::new');
    	$routes->get('getHotels', 'Request::getHotels');
    	$routes->get('getRooms', 'Request::getRooms');
    	$routes->post('submit', 'Request::submit');
    	$routes->get('view/(:num)', 'Request::view/$1');
    	$routes->get('edit/(:num)', 'Request::edit/$1');
    	$routes->post('update/(:num)', 'Request::update/$1');
    	$routes->get('delete/(:num)', 'Request::delete/$1');
    	$routes->get('messages/(:num)', 'Request::messages/$1');
    	$routes->get('activity/(:num)', 'Request::activity/$1');
    	$routes->post('reply/(:num)', 'Request::reply/$1');
    	$routes->post('updateStatus/(:num)', 'Request::updateStatus/$1');
      	$routes->get('searchFlights', 'Request::searchFlights');
		$routes->get('searchHotels', 'Request::searchHotels');
	});
  $routes->group('flight-management', ['filter' => 'admin-agent'], function($routes) {
    $routes->get('', 'FlightManagement::index');
    $routes->post('add', 'FlightManagement::add');
    $routes->post('delete/(:num)', 'FlightManagement::delete/$1');
	});
  
  $routes->group('room-management', ['filter' => 'admin-agent'], function($routes) {
    $routes->get('', 'RoomManagement::index');
    $routes->post('add', 'RoomManagement::add');
    $routes->post('delete/(:num)', 'RoomManagement::delete/$1');
    $routes->post('addRoomType', 'RoomManagement::addRoomType'); // Add this line
	});
  
	$routes->group('hotel-management', ['filter' => 'admin-agent'], function($routes) {
    	$routes->get('', 'HotelManagement::index');
    	$routes->post('add', 'HotelManagement::add');
    	$routes->get('edit/(:num)', 'HotelManagement::edit/$1');
    	$routes->post('update/(:num)', 'HotelManagement::update/$1');
    	$routes->post('delete/(:num)', 'HotelManagement::delete/$1');
    	$routes->post('toggleActive/(:num)', 'HotelManagement::toggleActive/$1');
	});
  
	$routes->group('room-management', ['filter' => 'admin-agent'], function($routes) {
        $routes->get('', 'RoomManagement::index');
        $routes->post('add', 'RoomManagement::add');
        $routes->post('delete/(:num)', 'RoomManagement::delete/$1');
    });
  
  $routes->group('city-management', ['filter' => 'admin-agent'], function($routes) {
        $routes->get('', 'CityManagement::index');
        $routes->post('add', 'CityManagement::add');
        $routes->post('delete/(:num)', 'CityManagement::delete/$1');
	});
  $routes->group('user-management', ['filter' => 'admin-agent'], function ($routes) {
    $routes->get('', 'UserManagement::index');
    $routes->get('add', 'UserManagement::add');
    $routes->post('add', 'UserManagement::add');
    $routes->get('edit/(:num)', 'UserManagement::edit/$1');
    $routes->post('edit/(:num)', 'UserManagement::edit/$1');
    $routes->post('delete/(:num)', 'UserManagement::delete/$1');
    $routes->post('toggle-user-status/(:num)', 'UserManagement::toggleUserStatus/$1');
    $routes->get('user-requests/(:num)', 'UserManagement::userRequests/$1');
	});

});
// The Auto Routing (Legacy) is very dangerous. It is easy to create vulnerable apps
// where controller filters or CSRF protection are bypassed.
// If you don't want to define all routes, please use the Auto Routing (Improved).
// Set `$autoRoutesImproved` to true in `app/Config/Feature.php` and set the following to true.
// $routes->setAutoRoute(false);

/*
 * --------------------------------------------------------------------
 * Route Definitions
 * --------------------------------------------------------------------
 */

// We get a performance increase by specifying the default
// route since we don't have to scan directories.
$routes->get('/', 'Home::index');

/*
 * --------------------------------------------------------------------
 * Additional Routing
 * --------------------------------------------------------------------
 *
 * There will often be times that you need additional routing and you
 * need it to be able to override any defaults in this file. Environment
 * based routes is one such time. require() additional route files here
 * to make that happen.
 *
 * You will have access to the $routes object within that file without
 * needing to reload it.
 */
if (is_file(APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php')) {
    require APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php';
}
