<?= $this->extend('layout/dashboard') ?>

<?= $this->section('content') ?>
<div class="card">
    <div class="card-header">
        <h3 class="card-title">Hotel Management</h3>
    </div>
    <div class="card-body">
        <button type="button" class="btn btn-primary mb-3" data-toggle="modal" data-target="#addHotelModal">
            Add New Hotel
        </button>
        <table class="table table-bordered table-striped" id="hotelTable">
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Name</th>
                    <th>City</th>
                    <th>Email</th>
                    <th>Agent Name</th>
                    <th>Status</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($hotels as $hotel): 
                    $cityName = 'Unknown';
                    foreach ($cities as $city) {
                        if ($city['id'] == $hotel['city_id']) {
                            $cityName = $city['name'];
                            break;
                        }
                    }
                ?>
                <tr>
                    <td><?= $hotel['id'] ?></td>
                    <td><?= esc($hotel['name']) ?></td>
                    <td><?= esc($cityName) ?></td>
                    <td><?= esc($hotel['email']) ?></td>
                    <td><?= esc($hotel['agent_name']) ?></td>
                    <td>
                        <div class="custom-control custom-switch">
                            <input type="checkbox" class="custom-control-input toggle-active" id="customSwitch<?= $hotel['id'] ?>" <?= $hotel['is_active'] ? 'checked' : '' ?> data-id="<?= $hotel['id'] ?>">
                            <label class="custom-control-label" for="customSwitch<?= $hotel['id'] ?>"><?= $hotel['is_active'] ? 'Active' : 'Inactive' ?></label>
                        </div>
                    </td>
                    <td>
                        <button class="btn btn-warning btn-sm edit-hotel" data-id="<?= $hotel['id'] ?>">Edit</button>
                        <button class="btn btn-danger btn-sm delete-hotel" data-id="<?= $hotel['id'] ?>">Delete</button>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<!-- The rest of your HTML and JavaScript code remains the same -->

<!-- Add Hotel Modal -->
<div class="modal fade" id="addHotelModal" tabindex="-1" role="dialog" aria-labelledby="addHotelModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="addHotelModalLabel">Add New Hotel</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <form id="addHotelForm">
                    <div class="form-group">
                        <label for="name">Hotel Name</label>
                        <input type="text" class="form-control" id="name" name="name" required>
                    </div>
                    <div class="form-group">
                        <label for="city_id">City</label>
                        <select class="form-control" id="city_id" name="city_id" required>
                            <option value="">Select City</option>
                            <?php foreach ($cities as $city): ?>
                                <option value="<?= $city['id'] ?>"><?= esc($city['name']) ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="form-group">
                        <label for="email">Email</label>
                        <input type="email" class="form-control" id="email" name="email" required>
                    </div>
                    <div class="form-group">
                        <label for="agent_name">Agent Name</label>
                        <input type="text" class="form-control" id="agent_name" name="agent_name" required>
                    </div>
                    <div class="form-group">
    <label for="room_types">Room Types</label>
    <select class="form-control select2" id="room_types" name="room_types[]" multiple required>
        <?php foreach ($roomTypes as $roomType): ?>
            <option value="<?= $roomType['id'] ?>"><?= esc($roomType['name']) ?></option>
        <?php endforeach; ?>
    </select>
</div>
                    <div class="form-group">
                        <div class="custom-control custom-switch">
                            <input type="checkbox" class="custom-control-input" id="is_active" name="is_active" checked>
                            <label class="custom-control-label" for="is_active">Active</label>
                        </div>
                    </div>
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                <button type="button" class="btn btn-primary" id="submitHotel">Add Hotel</button>
            </div>
        </div>
    </div>
</div>

<!-- Edit Hotel Modal -->
<div class="modal fade" id="editHotelModal" tabindex="-1" role="dialog" aria-labelledby="editHotelModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="editHotelModalLabel">Edit Hotel</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <form id="editHotelForm">
                    <input type="hidden" id="edit_id" name="id">
                    <div class="form-group">
                        <label for="edit_name">Hotel Name</label>
                        <input type="text" class="form-control" id="edit_name" name="name" required>
                    </div>
                    <div class="form-group">
                        <label for="edit_city_id">City</label>
                        <select class="form-control" id="edit_city_id" name="city_id" required>
                            <option value="">Select City</option>
                            <?php foreach ($cities as $city): ?>
                                <option value="<?= $city['id'] ?>"><?= esc($city['name']) ?></option>
                            <?php endforeach; ?>
                        </select>
                      </div>
                    <div class="form-group">
                        <label for="edit_email">Email</label>
                        <input type="email" class="form-control" id="edit_email" name="email" required>
                    </div>
                    <div class="form-group">
                        <label for="edit_agent_name">Agent Name</label>
                        <input type="text" class="form-control" id="edit_agent_name" name="agent_name" required>
                    </div>
                    <div class="form-group">
    					<label for="room_types">Room Types</label>
    					<select class="form-control select2" id="edit_room_types" name="room_types[]" multiple required>
        					<?php foreach ($roomTypes as $roomType): ?>
            				<option value="<?= $roomType['id'] ?>"><?= esc($roomType['name']) ?></option>
        					<?php endforeach; ?>
    					</select>
						</div>
                    <div class="form-group">
                        <div class="custom-control custom-switch">
                            <input type="checkbox" class="custom-control-input" id="edit_is_active" name="is_active">
                            <label class="custom-control-label" for="edit_is_active">Active</label>
                        </div>
                    </div>
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                <button type="button" class="btn btn-primary" id="updateHotel">Update Hotel</button>
            </div>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Initialize Select2
    $('.select2').select2({
        theme: 'bootstrap4',
        width: '100%'
    });

    // Initialize DataTable
    $('#hotelTable').DataTable();

    // Add Hotel
    document.getElementById('submitHotel').addEventListener('click', function() {
        var form = document.getElementById('addHotelForm');
        if (form.checkValidity()) {
            var formData = new FormData(form);
            fetch('<?= base_url('hotel-management/add') ?>', {
                method: 'POST',
                body: formData
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    alert(data.message);
                    location.reload();
                } else {
                    alert('Error: ' + (data.message || 'Unknown error occurred'));
                }
            })
            .catch(error => {
                console.error('Error:', error);
                alert('An error occurred. Please try again.');
            });
        } else {
            form.reportValidity();
        }
    });

    // Edit Hotel
    $('.edit-hotel').click(function() {
        var hotelId = $(this).data('id');
        $.ajax({
            url: '<?= base_url('hotel-management/edit') ?>/' + hotelId,
            type: 'GET',
            success: function(response) {
                console.log('Edit hotel response:', response); // Debug log
                if (response.success) {
                    var hotel = response.hotel;
                    $('#edit_id').val(hotel.id);
                    $('#edit_name').val(hotel.name);
                    $('#edit_city_id').val(hotel.city_id);
                    $('#edit_email').val(hotel.email);
                    $('#edit_agent_name').val(hotel.agent_name);
                    $('#edit_is_active').prop('checked', hotel.is_active == 1);
                    
                    // Handle room types
                    var editRoomTypes = $('#edit_room_types');
                    editRoomTypes.empty();
                    response.allRoomTypes.forEach(function(roomType) {
                        var option = new Option(roomType.name, roomType.id, false, false);
                        editRoomTypes.append(option);
                    });
                    
                    // Select the room types associated with this hotel
                    editRoomTypes.val(hotel.room_types);
                    editRoomTypes.trigger('change');

                    // Reinitialize Select2 for the room types select
                    editRoomTypes.select2({
                        theme: 'bootstrap4',
                        width: '100%'
                    });
                    
                    $('#editHotelModal').modal('show');
                } else {
                    alert('Error: ' + response.message);
                }
            },
            error: function(xhr, status, error) {
                console.error('Error:', error);
                alert('An error occurred while fetching hotel data.');
            }
        });
    });

    // Update Hotel
    $('#updateHotel').click(function() {
        var form = $('#editHotelForm');
        if (form[0].checkValidity()) {
            var formData = form.serialize();
            var hotelId = $('#edit_id').val();
            $.ajax({
                url: '<?= base_url('hotel-management/update') ?>/' + hotelId,
                type: 'POST',
                data: formData,
                success: function(response) {
                    if (response.success) {
                        alert(response.message);
                        location.reload();
                    } else {
                        alert('Error: ' + (response.message || 'Unknown error occurred'));
                    }
                },
                error: function(xhr, status, error) {
                    console.error('Error:', error);
                    alert('An error occurred. Please try again.');
                }
            });
        } else {
            form[0].reportValidity();
        }
    });

    // Delete Hotel
    document.querySelectorAll('.delete-hotel').forEach(function(button) {
        button.addEventListener('click', function() {
            if (confirm('Are you sure you want to delete this hotel?')) {
                var hotelId = this.dataset.id;
                fetch('<?= base_url('hotel-management/delete') ?>/' + hotelId, {
                    method: 'POST'
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        alert(data.message);
                        location.reload();
                    } else {
                        alert('Error: ' + data.message);
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    alert('An error occurred. Please try again.');
                });
            }
        });
    });

    // Toggle Active Status
    document.querySelectorAll('.toggle-active').forEach(function(toggle) {
        toggle.addEventListener('change', function() {
            var hotelId = this.dataset.id;
            fetch('<?= base_url('hotel-management/toggleActive') ?>/' + hotelId, {
                method: 'POST'
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    alert(data.message);
                } else {
                    alert('Error: ' + data.message);
                    this.checked = !this.checked; // Revert the toggle if there was an error
                }
            })
            .catch(error => {
                console.error('Error:', error);
                alert('An error occurred. Please try again.');
                this.checked = !this.checked; // Revert the toggle if there was an error
            });
        });
    });
});
</script>
<?= $this->endSection() ?>